package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcNetworkVolunteer;

/**
 * 网络文明自愿者Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface TcNetworkVolunteerMapper 
{
    /**
     * 查询网络文明自愿者
     * 
     * @param id 网络文明自愿者主键
     * @return 网络文明自愿者
     */
    public TcNetworkVolunteer selectTcNetworkVolunteerById(Long id);

    /**
     * 查询网络文明自愿者列表
     * 
     * @param tcNetworkVolunteer 网络文明自愿者
     * @return 网络文明自愿者集合
     */
    public List<TcNetworkVolunteer> selectTcNetworkVolunteerList(TcNetworkVolunteer tcNetworkVolunteer);

    /**
     * 新增网络文明自愿者
     * 
     * @param tcNetworkVolunteer 网络文明自愿者
     * @return 结果
     */
    public int insertTcNetworkVolunteer(TcNetworkVolunteer tcNetworkVolunteer);

    /**
     * 修改网络文明自愿者
     * 
     * @param tcNetworkVolunteer 网络文明自愿者
     * @return 结果
     */
    public int updateTcNetworkVolunteer(TcNetworkVolunteer tcNetworkVolunteer);

    /**
     * 删除网络文明自愿者
     * 
     * @param id 网络文明自愿者主键
     * @return 结果
     */
    public int deleteTcNetworkVolunteerById(Long id);

    /**
     * 批量删除网络文明自愿者
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcNetworkVolunteerByIds(Long[] ids);
}
