package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcNetworkVolunteer;
import com.ruoyi.zongzhi.service.ITcNetworkVolunteerService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络文明自愿者Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/volunteer")
@Api(tags = " 网络文明自愿者")
public class TcNetworkVolunteerController extends BaseController
{
    @Autowired
    private ITcNetworkVolunteerService tcNetworkVolunteerService;

    /**
     * 查询网络文明自愿者列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcNetworkVolunteer tcNetworkVolunteer)
    {
        startPage();
        List<TcNetworkVolunteer> list = tcNetworkVolunteerService.selectTcNetworkVolunteerList(tcNetworkVolunteer);
        return getDataTable(list);
    }

    /**
     * 导出网络文明自愿者列表
     */

    @PostMapping("/export")
    public void export(HttpServletResponse response, TcNetworkVolunteer tcNetworkVolunteer)
    {
        List<TcNetworkVolunteer> list = tcNetworkVolunteerService.selectTcNetworkVolunteerList(tcNetworkVolunteer);
        ExcelUtil<TcNetworkVolunteer> util = new ExcelUtil<TcNetworkVolunteer>(TcNetworkVolunteer.class);
        util.exportExcel(response, list, "网络文明自愿者数据");
    }

    /**
     * 获取网络文明自愿者详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcNetworkVolunteerService.selectTcNetworkVolunteerById(id));
    }

    /**
     * 新增网络文明自愿者
     */


    @PostMapping
    public AjaxResult add(@RequestBody TcNetworkVolunteer tcNetworkVolunteer)
    {
        tcNetworkVolunteer.setIsStatus(true);
        return toAjax(tcNetworkVolunteerService.insertTcNetworkVolunteer(tcNetworkVolunteer));
    }

    /**
     * 修改网络文明自愿者
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcNetworkVolunteer tcNetworkVolunteer)
    {
        return toAjax(tcNetworkVolunteerService.updateTcNetworkVolunteer(tcNetworkVolunteer));
    }

    /**
     * 删除网络文明自愿者
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcNetworkVolunteerService.deleteTcNetworkVolunteerByIds(ids));
    }
}
